
## Osiotk

## Description:

    os io toolkit

## Commands:

# Install Poetry:
#    python3 -m pip install poetry

# Build Package:
#    python3 -m poetry build

# Publish Package:
#    python3 -m poetry publish -u <username> -p <password>

# Install Package Locally:
#    python3 -m pip install osiotk==1.1.7

# Build And Publish Package:
#    python3 -m poetry build;python3 -m poetry publish -u <username> -p <password>

# Build Package; Publish Package; Install Package:
#    python3 -m poetry build;python3 -m poetry publish -u <username> -p <password>;python3 -m pip install osiotk==1.1.7

# Test Osiotk:
#    python3 -m pytest -rpP tests/

